Module errors

Module errors 

Possible returned error types if no match is found.

Enums

OverflowError
The possible numeric overflows that may occur.
SelectionError
Error types. Error types returned during the selection process when no match is found.