pub enum SelectionError {
InsufficentFunds,
IterationLimitReached,
MaxWeightExceeded,
Overflow(OverflowError),
ProgramError,
SolutionNotFound,
}Expand description
Error types. Error types returned during the selection process when no match is found.
Variants
InsufficentFunds
The sum of values passed is less than the target. That is, There is no possible solution.
IterationLimitReached
The maximum iteration count was reached returning no result. That is, A solution may exist but could not be found in a reasonable time.
MaxWeightExceeded
The weight of a selection exceeded the max weight limit returning no result.
That is, No solutions could be found that are less than the max_weight parameter.
Overflow(OverflowError)
A numeric overflow occurred and the selection process aborted returning no result.
ProgramError
A generic error that should not happen assuming code paths behave as known.
SolutionNotFound
Search space was exhausted without yielding a result. That is, iteration limit was not hit and yet no solution could be found.