Possible returned error types if no match is found.
Enums
- Overflow
Error - The possible numeric overflows that may occur.
- Selection
Error - Error types. Error types returned during the selection process when no match is found.
Possible returned error types if no match is found.